ResponsiveGridLayout class final

Example Build Function

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Theme.of(context).colorScheme.inversePrimary,
        title: Text(widget.title),
      ),
      body: ResponsiveGridLayout(
          columns: (constraints) => (constraints.span / 2).toInt(), // Each item covers two columns.
          breakpoints: materialLayoutBreakpoints,
          itemBuilder: (context, index) => Card(child: Center(child: Text('Item $index')))
      ),
    );
  }
Inheritance

Constructors

ResponsiveGridLayout({Key? key, bool debugOverlay = false, double? axisExtent, required AxisCalculator axisCount, required List<LayoutBreakpoint> breakpoints, required NullableIndexedWidgetBuilder itemBuilder})
const

Properties

axisCount → AxisCalculator
final
axisExtent double?
final
breakpoints List<LayoutBreakpoint>
final
debugOverlay bool
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder NullableIndexedWidgetBuilder
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited